#!/bin/bash
 
CURRENT_DIR=`pwd`


echo "installing RunMC on Windows/Cygwin:"  

# -----------  do not modify the settings below! ----------------------
#
# define here path to CERNLIB
CERN_DIR=$RUNMC"/build-win32/cern/cernlib" 
#
# Change to address of your CLHEP headers
CLHEPINC=$RUNMC"/build-win32/cern/clhep/include"
#
# name of PDF lib library from CERNLIB  
NAME_PDFLIB="pdflib"; 

#
# include path to CLHEP library here  
CLHEP_DIR=$RUNMC"/build-win32/cern/CLHEP/lib"

# specify name of CLHEP libarry 
NAME_CLHEP="CLHEP-g++.1.8.2.0"
#
# define here some additional library (if you need it for some reasons)
MYLIB=
#
# define additional include files
MYINCLUDE=

# specify compilers here (do not change this part!)
CXX="g++"
CC="gcc"
F77="g77"
AR="ar"


# make modern style
cp -f  $RUNMC/main/ws/styles/dot.wsrc_modern1 "$USERPROFILE"/.wsrc 

# is this linux? 
OSYSTEM=`uname`
if [ "$OSYSTEM" == "Linux" ]
then
echo "operating system=$OSYSTEM, not CYGWIN/Windows Stop";
exit 1;
fi

fcheck=`type -p $CC`
if test -x "$fcheck";
then
    echo " $fcheck -> OK $CC exists"
else
    echo "Error: $CC does not exists"
    exit 0;
fi


fcheck=`type -p $CXX`
if test -x "$fcheck";
then
    echo " $fcheck -> OK $CXX exists"
else
    echo "Error: $CXX does not exists"
    exit 0;
fi

fcheck=`type -p $F77`
if test -x "$fcheck";
then
    echo " $fcheck -> OK $F77 exists"
else
    echo "Error: $F77 does not exists"
    exit 0;
fi

fcheck=`type -p $AR`
if test -x "$fcheck";
then
    echo " $fcheck -> OK $AR  exists"
else
    echo "Error: $AR does not exists"
    exit 0;
fi


fcheck=`type -p ranlib`
if test -x "$fcheck";
then
    echo " $fcheck -> OK ranlib exists"
else
    echo "Error: ranlib does not exists"
    exit 0;
fi


fcheck=`type -p zip`
if test -x "$fcheck";
then
    echo " $fcheck -> OK zip exists"
else
    echo "Error: zip/unzip does not exists"
    exit 0;
fi




=`type -p sed`
if test -x "$fcheck";
then
    echo " $fcheck -> OK sed exists"
else
    echo "Error: sed does not exists"
    exit 0;
fi

fcheck=`type -p h2root`
if test -x "$fcheck";
then
    echo " $fcheck -> OK h2root exists"
else
    echo "Error: h2root does not exists. Is ROOT installed?"
    exit 0;
fi



# fcheck="/usr/lib/termcap/libtermcap.a"
# if test -e "$fcheck";
# then
#    echo " $fcheck -> OK libtermcap.a exists"
# else
#    echo "Error: Check your linux or cygwin distro!"
#    echo "Error: To compile CASCADE, you need to install \"libtermcap.a\""
#    echo "Error: RunMC expects this library in the standard place: "
#    echo "$fcheck"
#    exit 0;
# fi


pdflib=$CERN_DIR"/lib"$NAME_PDFLIB".a"
packlib=$CERN_DIR"/libpacklib.a"
kernlib=$CERN_DIR"/libkernlib.a"
incTROOT=$ROOTSYS"/include/TROOT.h"  
libCLHEPLIB=$CLHEP_DIR/"lib"$NAME_CLHEP".a"
incCLHEPLIB=$CLHEPINC/"CLHEP/config/CLHEP.h" 
incCLHEPvector=$CLHEPINC"/CLHEP/Vector/LorentzVector.h"
makeCLHEPLIB="-l"$NAME_CLHEP


## test invaromental variable 
if [ ! -f $RUNMC"/build/install.sh" ]
then
echo "You did not set \$RUNMC to correctly !  Stop installation"; 
echo "Example: \$RUNMC/build/install.sh should point to this script"  exit 1; 
else
echo " \$RUNMC set to $RUNMC  looks ok";
fi




## check cernlib libraries
if [ ! -f $mathlib ]
then
echo "cannot find $mathlib !  Stop installation"; exit 1; 
else
echo " $mathlib           looks ok"; 
fi

## check cernlib libraries
if [ ! -f $packlib ]
then
echo "cannot find $packlib !  Stop installation"; exit 1;
else
echo " $packlib           looks ok";
fi

## check cernlib libraries
if [ ! -f $kernlib ]
then
echo "cannot find $kernlib !  Stop installation"; exit 1;
else
echo " $kernlib           looks ok";
fi


## check cernlib libraries
if [ ! -f $pdflib ]
then
echo "cannot find $pdflib !  Stop installation"; exit 1;
else
echo " $pdflib            looks ok";
fi

## fast check for root existence 
if [ ! -f $incTROOT ]
then
echo "cannot find ROOT include files !  Is ROOT installed? Stop installation"; exit 1;
else
echo " $ROOTSYS/include/    \"include\" files      look ok";
fi

## fast check for root existence
if [ ! -f $libCLHEPLIB ]
then
echo "cannot find $libCLHEPLIB ! Is CLHEPLIB installed? Stop installation"; exit 1;
else
echo " $libCLHEPLIB found          looks ok"
fi



## fast check for CLHEP include existence
if [ ! -f $incCLHEPLIB ]
then
echo "cannot find $incCLHEPLIB ! -> Are CLHEPLIB include files installed? Stop installation"; exit 1;
else
echo " CLHEP/config/CLHEP.h               looks ok"
fi

## fast check for CLHEP include existence
if [ ! -f $incCLHEPvector ]
then
echo "cannot find $incCLHEPvector -> Are CLHEPLIB include files installed? Stop installation"; exit 1;
else
echo " CLHEP/Vector/LorentzVector.h       looks ok"
fi



# installog=$CURRENT_DIR"/install.log" 
if [ -f $installog ]
then
rm -f $installog
fi

if [ -f "Makefile.in" ]
then
rm -f "Makefile.in"
fi


echo " "


############################################################
############## making include Makefile ######################
cat > $CURRENT_DIR/Makefile.in <<!
#file generated by install.sh script (S.Chekanov) 

# CERNLIB location 
CERN_DIR = $CERN_DIR

# Change to address of your CLHEP headers
CLHEPINC     =  $CLHEPINC
#
#
# Change to address of your CLHEP library
CLHEP_DIR     = $CLHEP_DIR
#
#
# define here some additional library (if you need it for some reasons)
MYLIB         =
#
# define additional include files
MYINCLUDE     =
#
#
SRC_HOME = \$(shell pwd)

# Compilers
CXX          = $CXX 
FORTCOM      = $F77
OBJDIR       = ./
CC           = $CC
F77          = $F77
DEBUGCXX     = -Wall -Wno-format -O2
DEBUGF77     = -O
 
# Root variables
# Root variables
ROOTCFLAGS    = \$(shell root-config --cflags)
ROOTLIBS      = \$(shell root-config --libs)
ROOTGTTLIBS   = \$(shell root-config --glibs)
ROOTLIBS     += -lMinuit
# Assign or add variables
CERN          = -L\$(CERN_DIR)  -l$NAME_PDFLIB -lmathlib  -lpacklib -lkernlib -lm -lg2c
CLHEP         = -L\$(CLHEP_DIR) $makeCLHEPLIB
CXXFLAGS     += \$(ROOTCFLAGS)
LIBS         += \$(ROOTLIBS) \$(CERN) \$(CLHEP) \$(MYLIB)
MYINC         =../inc
ALL_INCLUDES =  \$(ROOTCFLAGS) -Iinc -I\$(MYINC) -I\$(CLHEPINC) -I\$(MYINCLUDE)
F77_INCLUDE  = -Iinc -I\$(CLHEPINC) -I\$(MYINC)

# end Makefile.in
!
#
date 
# start installation
#
#
MAKEFILELINUX=$RUNMC/"build/Makefile.in"
MAKEFILEWIN32=$RUNMC/"build-win32/Makefile.in" 

# now make some replacements
if [ -f "$MAKEFILELINUX" ]
then
cp -f $MAKEFILELINUX $RUNMC/"build/Makefile.in-linux"
fi
cp -f $MAKEFILEWIN32  $MAKEFILELINUX 


echo "Makefile.in is done !"
echo "Wait! -> installation.. It takes 3-10 minutes depending on CPU"
make -f Makefile

########
echo " "
echo "Messages:"
echo "  Be sure that acroread is installed"
echo "  edit $RUNMC/main/runmc/show_manual.sh to set correct PATH to acrobat.exe"
echo "  Otherwise you cannot look at the help using RunMC GUI"
echo " "
echo "  Make sure that \"JAVA\" is installed" 
echo ""
echo "see installation log in \"install.log\" "
echo "make clean     - remove all object files"
echo "make cleangui  - remove object files for RUNMC GUI" 
echo "make cleanmc   - remove all object files for Monte Carlo models"
echo "make cleanall  - clean all above + binary files"
echo "make all       - compile (output on the screen, no any configuration checks" 
echo "install        - compile everything with checks. Output goes to install.log file"
echo "" 
echo "RunMC is installed: binary files in $RUNMC/bin"

###############

exit 0

